def main():

	import matplotlib
	matplotlib.use('Agg')
	import glob
	import h5py
	import numpy
	import pylab
	import imageio
	
	def extract_snapshot_number(fpath):
	
		import re
		
		return int(re.search(r'_(\d+).',fpath).group(1))
	
	file_list = sorted(glob.glob('output/snapshot_*.h5'),
					   key=extract_snapshot_number)
	
	for fname in file_list:
		with h5py.File(fname,'r') as f:
			x_list = numpy.array(f['grid'])
			d_list = numpy.array(f['density'])
			p_list = numpy.array(f['pressure'])
			v_list = numpy.array(f['x_velocity'])
			time = numpy.array(f['time'])[0]
		pylab.subplot(311)
		pylab.plot(x_list, d_list, linewidth=4)
		#pylab.xlim((0,1))
		pylab.axvline(x=0, color='k')
		pylab.axvline(x=1, color='k')
		pylab.ylabel('density')
		pylab.subplot(312)
		pylab.plot(x_list, p_list, linewidth=4)
		#pylab.xlim((0,1))
		pylab.axvline(x=0, color='k')
		pylab.axvline(x=1, color='k')
		pylab.ylabel('pressure')
		pylab.subplot(313)
		pylab.plot(x_list, v_list, linewidth=4)
		#pylab.xlim((0,1))
		pylab.axvline(x=0, color='k')
		pylab.axvline(x=1, color='k')
		pylab.ylabel('velocity')
		pylab.xlabel('position')
		pylab.ylim((0,1))
		pylab.suptitle('t = %.2f' % time)
		pylab.savefig(fname.replace('.h5','.png'))
		pylab.close()
		
	with imageio.get_writer('animation.gif',
						   mode='I',
						   duration=0.1) as writer:
		for fname in file_list:
			image = imageio.imread(fname.replace('.h5','.png'))
			writer.append_data(image)
	
if __name__ == '__main__':

	main()